/*
 * Solution of scopa by edomora97
 * Try all the possible scenarios, ignore the invalid ones and
 * compute a metric to sort them and take the best.
 */

#include <assert.h>
#include <stdio.h>
#include <algorithm>
#include <iostream>
#include <tuple>
#include <vector>

struct card_t {
  int num;
  char suit;
};

std::ostream& operator<<(std::ostream& o, const card_t& c) {
  o << c.num << c.suit;
  return o;
}

bool possible(card_t c, std::vector<card_t>& table, int mask) {
  int sum = 0;
  for (int i = 0; i < table.size(); i++)
    if (mask & (1 << i)) sum += table[i].num;
  return sum == c.num;
}

int value(card_t c, std::vector<card_t>& table, int mask) {
  if (!possible(c, table, mask)) return -1;
  int value = 0;
  // 7 bello on hand
  if (c.num == 7 && c.suit == 'G') value += 1000;
  // 7 on hand
  if (c.num == 7) value += 30;
  for (int i = 0; i < table.size(); i++) {
    if (mask & (1 << i)) {
      // 7 bello on table
      if (table[i].num == 7 && table[i].suit == 'G') value += 1000;
      // 7 on table
      if (table[i].num == 7) value += 30;
      value += 1;
    }
  }
  // scopa
  if (mask == (1 << table.size()) - 1) {
    value += 100;
  }
  return value;
}

int main() {
  //  uncomment the following lines if you want to read/write from files
  //  freopen("input.txt", "r", stdin);
  //  freopen("output.txt", "w", stdout);

  std::vector<card_t> hand(3);
  std::vector<card_t> table(4);

  for (int i = 0; i < 3; i++) {
    int number;
    char suit;

    // card in hand
    assert(2 == scanf("%d%c", &number, &suit));
    hand[i] = {number, suit};
  }

  for (int i = 0; i < 4; i++) {
    int number;
    char suit;

    // card on table
    assert(2 == scanf("%d%c", &number, &suit));
    table[i] = {number, suit};
  }

  std::tuple<int, int, int> best = {-1, -1, 0};
  int freq = 0;

  // try to use the i-th card
  for (int i = 0; i < hand.size(); i++) {
    // try every possible combination of cards on the table
    for (int mask = 0; mask < (1 << table.size()); mask++) {
      int v = value(hand[i], table, mask);
      auto newSol = std::make_tuple(v, i, mask);
      if (v > std::get<0>(best)) {
        best = newSol;
        freq = 1;
      } else if (v == std::get<0>(best)) {
        freq++;
      }
    }
  }

  assert(freq == 1);

  std::cout << hand[std::get<1>(best)] << " ";
  for (int i = 0; i < table.size(); i++) {
    if (std::get<2>(best) & (1 << i)) {
      std::cout << table[i] << " ";
    }
  }
  std::cout << std::endl;
  return 0;
}
